@@ -12,89 +12,85 @@ data("crude")
 ### code chunk number 2: Ovid
 ###################################################
 txt <- system.file("texts", "txt", package = "tm")
-(ovid <- Corpus(DirSource(txt, encoding = "UTF-8"),
-                readerControl = list(language = "lat")))
+(ovid <- VCorpus(DirSource(txt, encoding = "UTF-8"),
+                 readerControl = list(language = "lat")))
 
 
 ###################################################
 ### code chunk number 3: VectorSource
 ###################################################
 docs <- c("This is a text.", "This another one.")
-Corpus(VectorSource(docs))
+VCorpus(VectorSource(docs))
 
 
 ###################################################
 ### code chunk number 4: Reuters
 ###################################################
 reut21578 <- system.file("texts", "crude", package = "tm")
-reuters <- Corpus(DirSource(reut21578),
-                  readerControl = list(reader = readReut21578XML))
+reuters <- VCorpus(DirSource(reut21578),
+                   readerControl = list(reader = readReut21578XMLasPlain))
 
 
 ###################################################
-### code chunk number 5: tm.Rnw:120-121 (eval = FALSE)
+### code chunk number 5: tm.Rnw:117-118 (eval = FALSE)
 ###################################################
 ## writeCorpus(ovid)
 
 
 ###################################################
-### code chunk number 6: tm.Rnw:132-133
+### code chunk number 6: tm.Rnw:128-129
 ###################################################
 inspect(ovid[1:2])
 
 
 ###################################################
-### code chunk number 7: tm.Rnw:137-138
+### code chunk number 7: tm.Rnw:133-135
 ###################################################
+meta(ovid[[2]], "id")
 identical(ovid[[2]], ovid[["ovid_2.txt"]])
 
 
 ###################################################
-### code chunk number 8: tm.Rnw:156-157
-###################################################
-reuters <- tm_map(reuters, as.PlainTextDocument)
-
-
-###################################################
-### code chunk number 9: tm.Rnw:165-166
+### code chunk number 8: tm.Rnw:149-150
 ###################################################
 reuters <- tm_map(reuters, stripWhitespace)
 
 
 ###################################################
-### code chunk number 10: tm.Rnw:171-172
+### code chunk number 9: tm.Rnw:155-156
 ###################################################
-reuters <- tm_map(reuters, tolower)
+reuters <- tm_map(reuters, content_transformer(tolower))
 
 
 ###################################################
-### code chunk number 11: Stopwords
+### code chunk number 10: Stopwords
 ###################################################
 reuters <- tm_map(reuters, removeWords, stopwords("english"))
 
 
 ###################################################
-### code chunk number 12: Stemming
+### code chunk number 11: Stemming
 ###################################################
 tm_map(reuters, stemDocument)
 
 
 ###################################################
-### code chunk number 13: tm.Rnw:204-206
+### code chunk number 12: tm.Rnw:187-190
 ###################################################
-query <- "id == '237' & heading == 'INDONESIA SEEN AT CROSSROADS OVER ECONOMIC CHANGE'"
-tm_filter(reuters, FUN = sFilter, query)
+idx <- meta(reuters, "id") == '237' &
+  meta(reuters, "heading") == 'INDONESIA SEEN AT CROSSROADS OVER ECONOMIC CHANGE'
+reuters[idx]
 
 
 ###################################################
-### code chunk number 14: DublinCore
+### code chunk number 13: DublinCore
 ###################################################
 DublinCore(crude[[1]], "Creator") <- "Ano Nymous"
 meta(crude[[1]])
 
 
 ###################################################
-### code chunk number 15: tm.Rnw:237-241
+### code chunk number 14: tm.Rnw:221-225
 ###################################################
 meta(crude, tag = "test", type = "corpus") <- "test meta"
 meta(crude, type = "corpus")
@@ -103,32 +99,32 @@ meta(crude)
 
 
 ###################################################
-### code chunk number 16: tm.Rnw:258-260
+### code chunk number 15: tm.Rnw:242-244
 ###################################################
 dtm <- DocumentTermMatrix(reuters)
-inspect(dtm[1:5,100:105])
+inspect(dtm[5:10, 740:743])
 
 
 ###################################################
-### code chunk number 17: tm.Rnw:269-270
+### code chunk number 16: tm.Rnw:253-254
 ###################################################
 findFreqTerms(dtm, 5)
 
 
 ###################################################
-### code chunk number 18: tm.Rnw:275-276
+### code chunk number 17: tm.Rnw:259-260
 ###################################################
 findAssocs(dtm, "opec", 0.8)
 
 
 ###################################################
-### code chunk number 19: tm.Rnw:288-289
+### code chunk number 18: tm.Rnw:268-269
 ###################################################
 inspect(removeSparseTerms(dtm, 0.4))
 
 
 ###################################################
-### code chunk number 20: tm.Rnw:303-305
+### code chunk number 19: tm.Rnw:283-285
 ###################################################
 inspect(DocumentTermMatrix(reuters,
                            list(dictionary = c("prices", "crude", "oil"))))
